==> julia-git-ordinarydiffeqloworderrk-src-1.1.0-2-any.pkg.tar.zst: usr/share/julia/arch-site/OrdinaryDiffEqLowOrderRK/src/OrdinaryDiffEqLowOrderRK.jl <==
module OrdinaryDiffEqLowOrderRK

import OrdinaryDiffEqCore: alg_order, isfsal, beta2_default, beta1_default,
                           alg_stability_size,
                           ssp_coefficient, OrdinaryDiffEqAlgorithm,
                           OrdinaryDiffEqExponentialAlgorithm,
                           explicit_rk_docstring, trivial_limiter!,
                           OrdinaryDiffEqAdaptiveAlgorithm,
                           unwrap_alg, @unpack, initialize!, perform_step!,
                           calculate_residuals,
                           calculate_residuals!, _ode_addsteps!, @OnDemandTableauExtract,
                           constvalue,
                           OrdinaryDiffEqMutableCache, uses_uprev,
                           OrdinaryDiffEqConstantCache, @fold,
                           @cache, CompiledFloats, alg_cache, CompositeAlgorithm,
                           copyat_or_push!,
                           AutoAlgSwitch, _ode_interpolant, _ode_interpolant!, full_cache,
                           accept_step_controller, DerivativeOrderNotPossibleError,
                           has_lazy_interpolation, du_cache, u_cache, get_fsalfirstlast
using SciMLBase
import MuladdMacro: @muladd
import FastBroadcast: @..
import LinearAlgebra: norm
import RecursiveArrayTools: recursivefill!, recursive_unitless_bottom_eltype
import Static: False
using DiffEqBase: @def, @tight_loop_macros
import OrdinaryDiffEqCore

using Reexport
@reexport using DiffEqBase

include("algorithms.jl")
include("alg_utils.jl")
include("low_order_rk_caches.jl")
include("low_order_rk_tableaus.jl")
include("interp_func.jl")
include("interpolants.jl")
include("low_order_rk_perform_step.jl")
include("low_order_rk_addsteps.jl")
include("split_perform_step.jl")
include("fixed_timestep_perform_step.jl")

export Euler, SplitEuler, Heun, Ralston, Midpoint, RK4,
       BS3, OwrenZen3, OwrenZen4, OwrenZen5, BS5,
       DP5, Anas5, RKO65, FRK65, RKM, MSRK5, MSRK6,
       PSRK4p7q6, PSRK3p5q4, PSRK3p6q5, Stepanov5, SIR54,
       Alshina2, Alshina3, Alshina6, AutoDP5

end

==> julia-git-ordinarydiffeqloworderrk-src-1.2.0-1-any.pkg.tar.zst: usr/share/julia/arch-site/OrdinaryDiffEqLowOrderRK/src/OrdinaryDiffEqLowOrderRK.jl <==
module OrdinaryDiffEqLowOrderRK

import OrdinaryDiffEqCore: alg_order, isfsal, beta2_default, beta1_default,
                           alg_stability_size,
                           ssp_coefficient, OrdinaryDiffEqAlgorithm,
                           OrdinaryDiffEqExponentialAlgorithm,
                           explicit_rk_docstring, generic_solver_docstring,
                           trivial_limiter!,
                           OrdinaryDiffEqAdaptiveAlgorithm,
                           unwrap_alg, @unpack, initialize!, perform_step!,
                           calculate_residuals,
                           calculate_residuals!, _ode_addsteps!, @OnDemandTableauExtract,
                           constvalue,
                           OrdinaryDiffEqMutableCache, uses_uprev,
                           OrdinaryDiffEqConstantCache, @fold,
                           @cache, CompiledFloats, alg_cache, CompositeAlgorithm,
                           copyat_or_push!,
                           AutoAlgSwitch, _ode_interpolant, _ode_interpolant!, full_cache,
                           accept_step_controller, DerivativeOrderNotPossibleError,
                           du_cache, u_cache, get_fsalfirstlast
using SciMLBase
import MuladdMacro: @muladd
import FastBroadcast: @..
import LinearAlgebra: norm
import RecursiveArrayTools: recursivefill!, recursive_unitless_bottom_eltype
import Static: False
using DiffEqBase: @def, @tight_loop_macros
import OrdinaryDiffEqCore

using Reexport
@reexport using DiffEqBase

include("algorithms.jl")
include("alg_utils.jl")
include("low_order_rk_caches.jl")
include("low_order_rk_tableaus.jl")
include("interp_func.jl")
include("interpolants.jl")
include("low_order_rk_perform_step.jl")
include("low_order_rk_addsteps.jl")
include("split_perform_step.jl")
include("fixed_timestep_perform_step.jl")

export Euler, SplitEuler, Heun, Ralston, Midpoint, RK4,
       BS3, OwrenZen3, OwrenZen4, OwrenZen5, BS5,
       DP5, Anas5, RKO65, FRK65, RKM, MSRK5, MSRK6,
       PSRK4p7q6, PSRK3p5q4, PSRK3p6q5, Stepanov5, SIR54,
       Alshina2, Alshina3, Alshina6, AutoDP5

end
